{
  config,
  pkgs,
  lib,
  ...
}:
let
  overlay = final: super: {
    makeModulesClosure = x: super.makeModulesClosure (x // { allowMissing = true; });
  };
in
{
  # compressed image is just harder to flash
  sdImage.compressImage = false;

  # workaround for error with missing packages, not sure if still required when building in docker
  nixpkgs.overlays = [ overlay ];
  nixpkgs.hostPlatform = "aarch64-linux";

  # Enable flakes and new 'nix' command
  nix.settings.experimental-features = [
    "nix-command"
    "flakes"
  ];
  # Workaround for https://github.com/NixOS/nix/issues/9574
  nix.settings.nix-path = config.nix.nixPath;
  networking.hostName = "pi";

  time.timeZone = "Europe/Berlin";
  i18n.defaultLocale = "de_DE.UTF8";

  environment.systemPackages = with pkgs; [
    # not quite sure why these are needed
    libraspberrypi
    raspberrypi-eeprom
  ];

  # Just a marker what the first installed version was
  # Ensures database files are kept backwards compatible with data from this version
  system.stateVersion = "24.05";
}
